package cn.com.qmth.examcloud.core.reports.api.controller;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import cn.com.qmth.examcloud.api.commons.exchange.PageInfo;
import cn.com.qmth.examcloud.api.commons.security.bean.User;
import cn.com.qmth.examcloud.commons.exception.StatusException;
import cn.com.qmth.examcloud.core.reports.base.bean.AddProjectReq;
import cn.com.qmth.examcloud.core.reports.base.bean.ProjectBean;
import cn.com.qmth.examcloud.core.reports.base.bean.QueryProjectPageReq;
import cn.com.qmth.examcloud.core.reports.base.bean.UpdateProjectReq;
import cn.com.qmth.examcloud.core.reports.base.enums.DataOrigin;
import cn.com.qmth.examcloud.core.reports.service.ProjectService;
import cn.com.qmth.examcloud.web.support.ControllerSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

@RestController
@Api(tags = "项目列表")
@RequestMapping("${$rmp.ctr.reports}/" + "project")
public class ProjectController extends ControllerSupport {
	@Autowired
	private ProjectService projectService;
	
    @PostMapping("/add")
    @ApiOperation(value = "新增项目")
    public Long addProject(@RequestBody @Valid AddProjectReq req) {
    	if(req.getDataOrigin().equals(DataOrigin.SYNC)&&(req.getExamIds()==null||req.getExamIds().size()==0)) {
    		throw new StatusException("1000001", "请选择考试");
    	}
    	if(req.getDataOrigin().equals(DataOrigin.IMPORT)) {
    		throw new StatusException("1000002", "暂不支持导入");
    	}
    	User user=getAccessUser();
        return projectService.addProject(req,user.getRootOrgId());
    }
    @PostMapping("/update")
    @ApiOperation(value = "修改项目")
    public void updateProject(@RequestBody @Valid UpdateProjectReq req) {
    	User user=getAccessUser();
        projectService.updateProject(req,user.getRootOrgId());
    }
    @PostMapping("/enable")
    @ApiOperation(value = "启用禁用")
    public void updateEnable(@RequestParam(required = true)@NotBlank(message = "请选择项目") @ApiParam(value = "项目Id集合") String ids,
    		@RequestParam(required = true)  @ApiParam(value = "启用/禁用") Boolean enable) {
    	User user=getAccessUser();
        projectService.updateEnable(ids, enable, user.getRootOrgId());
    }
    @PostMapping("page/{pageNo}/{pageSize}")
    @ApiOperation(value = "项目列表分页查询")
    public PageInfo<ProjectBean> queryPage(@RequestBody QueryProjectPageReq req,
                                        @PathVariable @ApiParam(value = "pageNo = 1,2,3...") Integer pageNo, @PathVariable Integer pageSize) {
    	User user=getAccessUser();
    	return projectService.queryPage(req, pageNo, pageSize,user.getRootOrgId());
    }

}